@@ -53,9 +53,19 @@ class StateMachine():
     def verbose(self, val):
         self._verbose = val
 
-    def on_line(line):
+    def on_line(self, line):
         pass
 
+    def start(self, next_state_name, lines_getter):
+        """まず state_machine.arrive(...) を行い、
+        そのあと leave(...), arrive(...) のペアを無限に繰り返します。
+        leave(...) に渡す line 引数は arrive(...) から返しますが、
+        代わりに None を返すと lines_getter() が実行されます。
+        lines_getter() は、 line のリストを返す関数です。
+        lines_getter() が None を返すとループを抜けます"""
+        self.arrive_sequence(next_state_name)
+        self.leave_and_loop(lines_getter)
+
     def leave_and_loop(self, lines_getter):
         """まず state_machine.leave(...) を行い、
         そのあと arrive(...), leave(...) のペアを無限に繰り返します。
@@ -150,6 +160,7 @@ class StateMachine():
         edge_name = self._state.leave(self._context, line)
 
         # さっき去ったステートの名前と、今辿っているエッジの名前
+        # Version 4.0.0
         key = f"{self._state.name}{edge_name}"
 
         if key in self._transition_dict:
@@ -159,6 +170,18 @@ class StateMachine():
                 print(f"[state_machine] Leave {key}{next_state_name}")
 
         else:
+            # Version 4.0.1
+            if self.state.name in self._transition_dict:
+                current_state_dict = self._transition_dict[self.state.name]
+
+                if edge_name in current_state_dict:
+                    next_state_name = current_state_dict[edge_name]
+
+                    if self.verbose:
+                        print(
+                            f"[state_machine] Leave {self.state.name} {edge_name} {next_state_name}")
+
+        if next_state_name is None:
             # Error
             raise ValueError(f"Leave-key [{key}] is not found")
 
